@@ -24,6 +24,7 @@ def _multiline_exception(text):
     text = text.strip()
     return (text.startswith('\\') or   # Special Command
             text.endswith(';') or      # Ended with a semi-colon
-            (text == 'exit') or        # Exit and Quit doesn't need semi-colon
-            (text == 'quit')
+            (text == 'exit') or        # Exit doesn't need semi-colon
+            (text == 'quit') or        # Quit doesn't need semi-colon
+            (text == '')               # Just a plain enter without any text
             )
